vpnengine/pkiservice/src/pkimapper.cpp
branchRCL_3
changeset 49 5960d2d03390
parent 44 735de8341ce4
--- a/vpnengine/pkiservice/src/pkimapper.cpp	Wed Sep 15 13:20:54 2010 +0300
+++ b/vpnengine/pkiservice/src/pkimapper.cpp	Wed Oct 13 15:42:16 2010 +0300
@@ -432,9 +432,11 @@
         if(mapping->IsMatchingL(aDescriptor, aInfoOnly, aStoreType))
             {
             // If we found a match, process it further
-            _LIT(KJavaTrustRootLabel, "Java Trust Root");
-            // Discard all "Java Trust Root" certificates to avoid label-mapping problem
-            if (mapping->Label().Compare(KJavaTrustRootLabel) != 0)
+            _LIT(KMidp2Label, "MIDP2");
+            TBuf<12> buf;
+            buf.Append(KMidp2Label);
+            // Discard all MIDP2 certificates to avoid label-mapping problem
+            if (buf.Compare(mapping->Label()) != 0)
                 {
                 if(mapping->EndTime() > furthestEndTime)
                     {
@@ -446,7 +448,7 @@
                 }
             else 
                 {
-                LOG(Log::Printf(_L("Found a cert, but it was a \"Java Trust Root\" one - continuing search")));
+                LOG(Log::Printf(_L("Found a cert, but it was a MIDP2 one - continuing search")));
                 }
             }
         }